16.35. cdist-type__daemontools(7) — cdist 6.5.4 documentation

# 16.35. cdist-type__daemontools(7)

## 16.35.1. NAME

cdist-type__daemontools - Install daemontools

## 16.35.2. DESCRIPTION

Install djb daemontools and (optionally) an init script.

## 16.35.3. REQUIRED PARAMETERS

None.

## 16.35.4. OPTIONAL PARAMETERS

from-package
  Package to install. Must be compatible with the original daemontools. Example: daemontools-encore. Default: daemontools.
servicedir
  Directory to scan for services. Default: /service

## 16.35.5. BOOLEAN PARAMETERS

install-init-script
  Add an init script and set it to start on boot.

## 16.35.6. EXAMPLES

    __daemontools --from-package daemontools-encore  # if you prefer

## 16.35.7. SEE ALSO

cdist-type__daemontools_service(7)

## 16.35.8. AUTHORS

Kamila Součková <kamila--@--ksp.sk>

## 16.35.9. COPYING

Copyright (C) 2017 Kamila Součková. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.